@@ -12,19 +12,15 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import bunch
 import os
 import subprocess
 import yaml
 
-from oslo_log import log as logging
-
+from muranoagent import bunch
 import muranoagent.exceptions
 from muranoagent import executors
 from muranoagent.executors import chef_puppet_executor_base
 
-LOG = logging.getLogger(__name__)
-
 
 @executors.executor('Puppet')
 class PuppetExecutor(chef_puppet_executor_base.ChefPuppetExecutorBase):
@@ -54,15 +50,14 @@ class PuppetExecutor(chef_puppet_executor_base.ChefPuppetExecutorBase):
                         (self.module_name, self.module_recipe, e.strerror),
                 additional_data=result)
 
-        path = os.path.abspath(self._path + "/files/")
         command = 'puppet apply --hiera_config=hiera.yaml --modulepath ' \
-                  '{0} manifest.pp'.format(path)
+                  '{0} manifest.pp'.format(self._path)
         result = self._execute_command(command)
         return bunch.Bunch(result)
 
     def _configure_puppet(self):
 
-        if os.path.exists('hiera.yam'):
+        if os.path.exists('hiera.yaml'):
             return
 
         data = dict(
